Installation
============

scikit-COSMO is, by design, relatively lightweight, and only requires that `numpy <numpy.org>`_
and the most recent release of `scikit-learn <scikit-learn.org>`_ be installed.

Install from source 
###################

.. code-block:: bash

  git clone https://github.com/cosmo-epfl/scikit-cosmo
  cd scikit-cosmo
  python setup.py install --user

You're ready to import skcosmo from your code! Have a look at the :ref:`api-reference` for how to use the code.
